summaryrefslogtreecommitdiffstats
path: root/kompare/libdialogpages/pagebase.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kompare/libdialogpages/pagebase.cpp')
-rw-r--r--kompare/libdialogpages/pagebase.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/kompare/libdialogpages/pagebase.cpp b/kompare/libdialogpages/pagebase.cpp
index ef9aa1ea..4feda39b 100644
--- a/kompare/libdialogpages/pagebase.cpp
+++ b/kompare/libdialogpages/pagebase.cpp
@@ -22,7 +22,7 @@
#include "pagebase.h"
-PageBase::PageBase( TQWidget* parent ) : KTabCtl( parent )
+PageBase::PageBase( TQWidget* tqparent ) : KTabCtl( tqparent )
{
}
@@ -33,12 +33,12 @@ PageBase::~PageBase()
}
/** No descriptions */
-TQSize PageBase::sizeHintForWidget( TQWidget* widget )
+TQSize PageBase::tqsizeHintForWidget( TQWidget* widget )
{
//
// The size is computed by adding the sizeHint().height() of all
// widget children and taking the width of the widest child and adding
// layout()->margin() and layout()->spacing()
//
// this code in this method has been ripped out of a file in kbabel
@@ -47,17 +47,17 @@ TQSize PageBase::sizeHintForWidget( TQWidget* widget )
TQSize size;
int numChild = 0;
- TQObjectList *l = (TQObjectList*)(widget->children());
+ TQObjectList l = widget->childrenListObject();
- for( uint i=0; i < l->count(); i++ )
+ for( uint i=0; i < l.count(); i++ )
{
- TQObject *o = l->at(i);
+ TQObject *o = l.at(i);
if( o->isWidgetType() )
{
numChild += 1;
TQWidget *w=((TQWidget*)o);
- TQSize s = w->sizeHint();
+ TQSize s = w->tqsizeHint();
if( s.isEmpty() == true )
{
s = TQSize( 50, 100 ); // Default size
@@ -72,8 +72,8 @@ TQSize PageBase::sizeHintForWidget( TQWidget* widget )
if( numChild > 0 )
{
- size.setHeight( size.height() + widget->layout()->spacing()*(numChild-1) );
- size += TQSize( widget->layout()->margin()*2, widget->layout()->margin()*2 + 1 );
+ size.setHeight( size.height() + widget->tqlayout()->spacing()*(numChild-1) );
+ size += TQSize( widget->tqlayout()->margin()*2, widget->tqlayout()->margin()*2 + 1 );
}
else
{
@@ -33,12 +33,12 @@ PageBase::~PageBase()
{
//
- // The size is computed by adding the sizeHint().height() of all
- // widget children and taking the width of the widest child and adding
- // layout()->margin() and layout()->spacing()
+ // The size is computed by adding the tqsizeHint().height() of all
+ // widget tqchildren and taking the width of the widest child and adding
+ // tqlayout()->margin() and tqlayout()->spacing()
//
// this code in this method has been ripped out of a file in kbabel